function market=market(SS,DT,r,D,N_STD,format_dt,Output)

%market (SS,DT,r,D,Output)
% SS = REAL MARKET DATA (data from .....)
% DT = date of the data  (# of data, year, month, day, dt (day), dt (year))
%  r = riskfree
%  D = dividend
%  N_STD = Number of data to consider to calculate the MEAN and STD
%  format_dt
%  format_dt=1 then dt = (number of data)/365 or 366  (depending the year)
%  format_dt=2 then dt = (number of data + vacations and weekneds)/365 or 366  (depending the year)
%
% Output =
%
%  0 = name of the data
%  1 = N = number of data
%  2 = NM = number of stocks 
%  3 = dt = delta T (annual)
%  4 = dS = S(1+1)-S(i) = A(S,t)+B(S,t)
%  5 = ds = dS/S(t)
%  6 = A(S,t) = S(r-D)dt
%  7 =   a(t) = (r-D)dt
%  8 = B(S,t) = dS - S(r-D)dt = dS - A(S,t)= S*vol*dX
%  9 =   b(t) = ds - (r-D)dt = ds - a(t) = vol*dX
% 10 = MEAN = mean = Sum(S(i)/N)
% 11 =  STD = standar desviation = sqrt(Sum{(S(i)-mean(i))^2/(n-1)})
% 12 =  vol = volatility = STD/S(i)
% 13 =   dX = B(S,t)/(vol*S(i)); = (dS-(r-D)dt)/(S*vol)    
% 14 =   dx = b(t)/vol;  = (dS-(r-D)dt)/vol                 
% 15 =  z_X = b(t)/(vol*sqrt(dt));                   Random number
% 16 =    S to plot, with the same number of dt.
% example
% name=market(SS_W,dt_W,r,D,N_STD,format_dt,0);
% N=market(SS_W,dt_W,r,D,N_STD,format_dt,1);
% NM=market(SS_W,dt_W,r,D,N_STD,format_dt,2);
% dt=market(SS_W,dt_W,r,D,N_STD,format_dt,3);
% dS=market(SS_W,dt_W,r,D,N_STD,format_dt,4);
% ds=market(SS_W,dt_W,r,D,N_STD,format_dt,5);
% A=market(SS_W,dt_W,r,D,N_STD,format_dt,6);
% a=market(SS_W,dt_W,r,D,N_STD,format_dt,7);
% B=market(SS_W,dt_W,r,D,N_STD,format_dt,8);
% b=market(SS_W,dt_W,r,D,N_STD,format_dt,9);
% MEAN=market(SS_W,dt_W,r,D,N_STD,format_dt,10);
% STD=market(SS_W,dt_W,r,D,N_STD,format_dt,11);
% vol=market(SS_W,dt_W,r,D,N_STD,format_dt,12);
% dX=market(SS_W,dt_W,r,D,N_STD,format_dt,13);
% dx=market(SS_W,dt_W,r,D,N_STD,format_dt,14);
% z_X=market(SS_W,dt_W,r,D,N_STD,format_dt,15);
% SS_Plot=market(SS_W,dt_W,r,D,N_STD,format_dt,16);
%
format_vol=1;
%%
%%
%Definition of matrix sizes
N=size(SS,1);
NM=size(SS,2);

%Definition of dt
for i=1:N-1
   if format_dt==1
        if DT(i,2)==2001
        dt(i,1)=1/253;
        else
        dt(i,1)=1/252;
        end
    elseif format_dt==2
        if DT(i,2)==2000
        dt(i,1)=DT(i,5)/366;
        else
        dt(i,1)=DT(i,5)/365;
        end
   end
end
N_dt=size(dt,1);

if     DT(1,1)<22
            T_start=1998+((252-22+DT(1,1))/252);
elseif DT(1,1)>=23 & DT(1,1)<274
            T_start=1999+((DT(1,1)-22)/252);
elseif DT(1,1)>=274 & DT(1,1)<526
            T_start=2000+((DT(1,1)-274)/252);
elseif DT(1,1)>=526 & DT(1,1)<779
            T_start=2001+((DT(1,1)-526)/253);
elseif DT(1,1)>=779 & DT(1,1)<1031
            T_start=2002+((DT(1,1)-779)/252);
elseif DT(1,1)>=1031 & DT(1,1)<1283
            T_start=2003+((DT(1,1)-1031)/252);         
end
%
for i=1:N_dt
   if i==1
       name(i,1)=T_start;
   else
       name(i,1)=name(i-1,1)+dt(i-1);
   end
end

%Definition of ds,A,B1,B2,MEAN,STD
for i=1:N_dt
for j=1:NM
    dS(i,j)=SS(i+1,j)-SS(i,j);
    ds(i,j)=dS(i,j)/SS(i,j);
    A(i,j)=SS(i,j)*(r-D);
    a(i,j)=(r-D)*dt(i);
    B(i,j)=dS(i,j)-A(i,j)*dt(i);
    b(i,j)=ds(i,j)-a(i,j);
    SS_Plot(i,j)=SS(i,j);
end  
     if size(SS_Plot,1)>N_STD
         conta=size(SS_Plot,1)-N_STD;
         for k=1:N_STD
         SS_calculation(k,:)=SS_Plot(k+conta,:);
         end
         conta=conta+1;
     else
         SS_calculation(i,:)=SS_Plot(i,:);
     end
     if format_vol==1
         MEAN(i,:)=mean(SS_calculation,1);
         if i==1
         STD(1,:)=zeros(1,NM);
         else
         STD(i,:)=std(SS_calculation);
         end
         for j=1:NM 
         vol(i,j)=STD(i,j)/SS(i,j);
         end
     elseif format_vol==2
         for j=1:NM 
         MEAN(i,j)=sum(ds(:,j))/(i*dt(i));
         STD_matriz1(i,j)=((ds(i,j)-MEAN(i,j))^2);
         end
         if i==1
         STD(1,:)=zeros(1,NM);
         else
         STD(i,:)=sum(STD_matriz1)/((i-1)*dt(i));
         end
         for j=1:NM 
         vol(i,j)=sqrt(STD(i,j));
         end
     end
end

for i=1:N_dt
for j=1:NM
    if i==1
    dX(1,:)=zeros(1,NM);
    dx(1,:)=zeros(1,NM);
    z_X(1,:)=zeros(1,NM);
    else
    if vol(i,j)==0    dX(i,j)=0;  dx(i,j)=0;  z_X(i,j)=0;      
    else  
        dX(i,j)=B(i,j)/(vol(i,j)*SS(i,j));
        dx(i,j)=b(i,j)/vol(i,j);
        z_X(i,j)=b(i,j)/(vol(i,j)*sqrt(dt(i)));
    end
    end
end
end

if Output==0         market=name;
elseif Output==1     market=N;
elseif Output==2     market=NM;
elseif Output==3     market=dt;
elseif Output==4     market=dS;
elseif Output==5     market=ds;    
elseif Output==6     market=A;
elseif Output==7     market=a;  
elseif Output==8     market=B;
elseif Output==9     market=b;
elseif Output==10    market=MEAN;
elseif Output==11    market=STD;
elseif Output==12    market=vol;
elseif Output==13    market=dX;
elseif Output==14    market=dx;     
elseif Output==15    market=z_X;
elseif Output==16    market=SS_Plot;  

else 
    error(sprintf('Please select the correct output!! type help market'))
end

clear i j N NM time_work ans N_STD;