%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Property of Klaus Schmitz Abe,                                    %%
%% schmitz@maths.ox.ac.uk                                            %%
%% Oxford Centre for Industrial and Applied Mathematics (OCIAM)      %%
%% This file represents work in progress, and has been prepared      %%
%% solely for educational purposes. It has not yet been subject      %%
%% to detailed technical review and may contain material errors.     %%
%% Do NOT forward to others without first contacting the author      %%
%% for (a) permission, (b) any errata/updates. Neither the author    %%
%% nor OCCIAM accepts any responsibility for any financial or        %%
%% other consequences arising from the use or misuse of the          %%
%% material enclosed in this notebook.                               %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Last update 15-OCT-2003
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    data.MAT
%
% Names of the data from the principal matrices
%
% MATRIX DT
%       1            2        3      4          5           6
% # of the data	    Year    Month	day	    dt(daily)	dt(annual)
%
%   YEAR     number of DATA   VACATIONS     weekends                   DAYS
%   1998-Nov	  1  [1-1]	        0            0 =   8 days             1
%   1998-DEC	 21  [2-21]	        3            4 =   8 days            31
%   1999		252	 [22-273]	    9           52 = 104 days           365
%   2000		252	 [274-525]	    8           53 = 106 days           366        
%   2001		253	 [526-778]	    8           52 = 104 days           365
%   2002		252	 [779-1030]	    9           52 = 104 days           365
%   2003-SEP    189  [1031-1219]    6		    39 =  78 days			273
%      TOTAL   1219		           43		   252 = 504 days		   1766
%
% MATRIX SS_L   LONDON
%    1        2      3        4      5        6       7       8       9          10
% 	        Gross				            FTSE	FTSE		    FTSE A		
%   FTSE	div	    P/E	    FTSE	FTSE	Small	A All		    Fledg-	    FTSE
%   100	    yield	ratio	250	    A 350	Cap	    Share	FT 30	ling	    AIM	
%
% MATRIX SS_I   INTERNATIONAL
%      1            2        3            4      5
%	  FTSE		            Dow		            FT-A
%     Eurotop	    Dax	    Jones	    Nikkei	World
%	  300		            Ind Avg	    225	    ($)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% INPUTS %%%%%
%
% 1) Recalculate input data.mat
% If recalculate = 1 --> close everything and calculate again the data.mat;
%                = 0 --> only plot and not recalculate all variables.
Recalculate=1;      % YES = 1, NO = 0

% Subroutine
if Recalculate==1
format long
clear all; close all; load market_september.mat; Recalculate=1; format long;
else
close all; format long;
end

% 2) Main inputs
% NOTE IMPORTANT-- you have to recalculate if you change one o more main inputs 
LONDON=[1,5];      % LONDON = DATA NUMBER = [1,2,3,4,5,6,7,8,9,10];   
INTERNATIONAL=[1,2,3,4];          % INTERNATIONAL = DATA NUMBER = [1,2,3,4,5];
r=0.05;                     % riskfree
D=0.01;                     % dividend
time_work=[1,1219];         % time interval
N_STD=100;                  % number of data to calculate the MEAN and STD
format_dt=1;                % type of dt to use in the calculations
                            % format_dt=1 then dt = (number of data)/365 or 366  (depending the year)
                            % format_dt=2 then dt = (number of data + vacations and weekneds)/365 or 366

% 3) PLOTS     [x1,x2,x3,x4]
%              x1= view plot; YES = 1, NO = 0
%              x2= use fixed scales for all subplots; YES = 1, NO = 0
%              x3= ylim_down 
%              x4= ylim_up
% NOTE IMPORTANT-- you dont have to recalculate if you change the plot parameters

% X axis
xlim_down=1998.9;
xlim_up=2005;

% Y axis
P_SS =      [1,1,0,21000];           % Stock price
P_dt =      [1,0,0.00395,0.004];     % format_dt=1
                                     % dt = 1 year / number of data                   
                                     % dt=1/253 year 2001; dt=1/252 others; 
                                     % format_dt=2
                                     % dt = (number of data + vacations + weekneds)/365 or 366
                                     % if 2000 --> dt=DT/366;  else dt=DT/365;
P_dS =      [1,1,-1000,1000];        % dS = S(t+1)-S(t)                          dS(i,j)=SS(i+1,j)-SS(i,j);
P_ds =      [1,1,-0.1,0.1];          % ds = dS/S(t)                              ds(i,j)=dS(i,j)/SS(i,j);
P_A =       [1,0,0,1000];            % A = S(r-D)dt                              A(i,j)=SS(i,j)*(r-D);
P_a =       [1,0,0,.0002];           % a = (r-D)dt                               a(i,j)=(r-D)*dt(i);
P_B =       [1,1,-500,500];          % B = dS - A = S*vol*dX                     B(i,j)=dS(i,j)-A(i,j)*dt(i);
P_b =       [1,1,-0.1,0.1];          % b = ds - a = vol*dX                       b(i,j)=ds(i,j)-a(i,j);
                                     %%%%         t=1,,,,n,,,,N_STD
P_MEAN =    [1,0,0,15000];           % MEAN = sum(S(t))/n                        MEAN(i,:)=mean(SS_Plot1,1);
P_STD =     [1,0,0,1500];            % STD = sqrt(sum(s(t)-MEAN)^2/n-1)          STD(i,:)=std(SS_Plot1);
P_vol =     [1,1,0,0.2];             % vol = STD/S                               vol(i,j)=STD(i,j)/SS(i,j);
P_dX =      [1,1,-2,2];              % dX = B/(vol*SS);        dX(1,:)=0
P_dx =      [1,1,-2,2];              % dx = b/vol=dX;          dx(1,:)=0
P_z  =      [1,1,-30,30];            % z = b/(vol*sqrt(dt));   z(1,:)=0
P_error =   [1,0];                   % error of calculation
P_error1 =  [-1e-12,1e-12];          % error_dS = dS-SS_W(i,j)*(r-D)*dt(i)+SS_W(i,j)*vol(i,j)*sqrt(dt(i))*z_X(i,j);       
P_error2 =  [-1e-16,1e-16];          % error_ds = ds-(r-D)*dt(i)+vol(i,j)*sqrt(dt(i))*z_X(i,j);
P_error3 =  [-1e-11,1e-11];          % error_S = SS_W(i+1,j)-(SS_W(i,j)+ SS_W(i,j)*(r-D)*dt(i)+SS_W(i,j)*vol(i,j)*sqrt(dt(i))*z_X(i,j));
P_error4 =  [-1e-16,1e-16];          % error_s = SS_W(i+1,j)-(SS_W(i,j)+ ((r-D)*dt(i)+vol(i,j)*sqrt(dt(i))*z_X(i,j))*SS_W(i,j));
%
% 4) Names of the stocks
LEGEND_L_1='FTSE-100';
LEGEND_L_2='Gross div yield';
LEGEND_L_3='P/E ratio';
LEGEND_L_4='FTSE-250';
LEGEND_L_5='FTSE-350';
LEGEND_L_6='FTSE Small Cap';
LEGEND_L_7='FTSE-A ALL Share';
LEGEND_L_8='FT 30';
LEGEND_L_9='FTSE-A Fledgling';
LEGEND_L_10='FTSE AIM';
LEGEND_I_1='FTSE-Eurotop-300';
LEGEND_I_2='Dax';
LEGEND_I_3='Dow Jones';
LEGEND_I_4='Nikkei 225';
LEGEND_I_5='FT-A World ($)';
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SUBROUTINE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Subprograms for plots
if Recalculate==1
N_col_legend=size(LONDON,2)+size(INTERNATIONAL,2);
Max_legend=[size(LEGEND_L_1,2);size(LEGEND_L_2,2);size(LEGEND_L_3,2);size(LEGEND_L_4,2);size(LEGEND_L_5,2);
            size(LEGEND_L_6,2);size(LEGEND_L_7,2);size(LEGEND_L_8,2);size(LEGEND_L_9,2);size(LEGEND_L_10,2);
            size(LEGEND_I_1,2);size(LEGEND_I_2,2);size(LEGEND_I_3,2);size(LEGEND_I_4,2);size(LEGEND_I_5,2)];
N_max_legend=max(Max_legend);
matriz_legend=zeros(N_col_legend,N_max_legend);
conta=1;
for i=1:size(LONDON,2)
    if LONDON(i)==1
    matriz_legend(conta,:)=[LEGEND_L_1,zeros(1,N_max_legend-size(LEGEND_L_1,2))];
    conta=conta+1;
    end
    if LONDON(i)==2
    matriz_legend(conta,:)=[LEGEND_L_2,zeros(1,N_max_legend-size(LEGEND_L_2,2))];
    conta=conta+1;
    end 
    if LONDON(i)==3
    matriz_legend(conta,:)=[LEGEND_L_3,zeros(1,N_max_legend-size(LEGEND_L_3,2))];
    conta=conta+1;
    end
    if LONDON(i)==4
    matriz_legend(conta,:)=[LEGEND_L_4,zeros(1,N_max_legend-size(LEGEND_L_4,2))];
    conta=conta+1;
    end
    if LONDON(i)==5
    matriz_legend(conta,:)=[LEGEND_L_5,zeros(1,N_max_legend-size(LEGEND_L_5,2))];
    conta=conta+1;
    end
    if LONDON(i)==6
    matriz_legend(conta,:)=[LEGEND_L_6,zeros(1,N_max_legend-size(LEGEND_L_6,2))];
    conta=conta+1;
    end
    if LONDON(i)==7
    matriz_legend(conta,:)=[LEGEND_L_7,zeros(1,N_max_legend-size(LEGEND_L_7,2))];
    conta=conta+1;
    end
    if LONDON(i)==8
    matriz_legend(conta,:)=[LEGEND_L_8,zeros(1,N_max_legend-size(LEGEND_L_8,2))];
    conta=conta+1;
    end
    if LONDON(i)==9
    matriz_legend(conta,:)=[LEGEND_L_9,zeros(1,N_max_legend-size(LEGEND_L_9,2))];
    conta=conta+1;
    end
    if LONDON(i)==10
    matriz_legend(conta,:)=[LEGEND_L_10,zeros(1,N_max_legend-size(LEGEND_L_10,2))];
    conta=conta+1;
    end
end
for i=1:size(INTERNATIONAL,2)
    if INTERNATIONAL(i)==1
    matriz_legend(conta,:)=[LEGEND_I_1,zeros(1,N_max_legend-size(LEGEND_I_1,2))];
    conta=conta+1;
    end
    if INTERNATIONAL(i)==2
    matriz_legend(conta,:)=[LEGEND_I_2,zeros(1,N_max_legend-size(LEGEND_I_2,2))];
    conta=conta+1;
    end
    if INTERNATIONAL(i)==3
    matriz_legend(conta,:)=[LEGEND_I_3,zeros(1,N_max_legend-size(LEGEND_I_3,2))];
    conta=conta+1;
    end
    if INTERNATIONAL(i)==4
    matriz_legend(conta,:)=[LEGEND_I_4,zeros(1,N_max_legend-size(LEGEND_I_4,2))];
    conta=conta+1;
    end
    if INTERNATIONAL(i)==5
    matriz_legend(conta,:)=[LEGEND_I_5,zeros(1,N_max_legend-size(LEGEND_I_5,2))];
    conta=conta+1;
    end
end
STOCK_TO_ANALIZE=char(matriz_legend)
% Define WORKSPACE DATA
% Error in the time_work
N=size(SS_L,1);
time_work(1,2)=time_work(1,2)+1;
if time_work(1,2) > N
   time_work(1,2) = N;
end
if time_work(1,1) < 1
   time_work(1,1) = 1;
end   
if time_work(1,1) > time_work(1,2)
   time_work(1,1) = 1;
   time_work(1,2) = N;
end
% Define Stock Work Matrix
for i=1:(time_work(1,2)-time_work(1,1)+1)
    for j=1:size(LONDON,2)
    SS_W(i,j)=SS_L(i+time_work(1,1)-1,LONDON(1,j));
    end
    for j=1:size(INTERNATIONAL,2)
    SS_W(i,j+size(LONDON,2))=SS_I(i+time_work(1,1)-1,INTERNATIONAL(1,j));
    end
end
% Define dt work Matrix
for i=1:(time_work(1,2)-time_work(1,1)+1)
    for j=1:size(SS_DT,2)
    dt_W(i,j)=SS_DT(i+time_work(1,1)-1,j);
    end
end
TIME_WORK=time_work;
end
TIME_WORK
%
%
%
% PLOTS
if Recalculate==1
name=market(SS_W,dt_W,r,D,N_STD,format_dt,0);
end

% z_X(i,j)=b(i,j)/(vol(i,j)*sqrt(dt(i)));     z_X(1,:)=0
if P_z(1,1)==1
if Recalculate==1
z_X=market(SS_W,dt_W,r,D,N_STD,format_dt,15);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,z_X(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('z=b/(vol*sqrt(dt))'); 
        end
        if P_z(1,2)==1
        ylim([P_z(1,3),P_z(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs z')
end
end

% dx(i,j)=b(i,j)/vol(i,j);                  dx(1,:)=0
if P_dx(1,1)==1
if Recalculate==1
dx=market(SS_W,dt_W,r,D,N_STD,format_dt,14);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,dx(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('dx=b/vol=dX;'); 
        end
        if P_dx(1,2)==1
        ylim([P_dx(1,3),P_dx(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs dx(t)')
end
end

% dX(i,j)=B(i,j)/(vol(i,j)*SS(i,j));        dX(1,:)=0
if P_dX(1,1)==1
if Recalculate==1
dX=market(SS_W,dt_W,r,D,N_STD,format_dt,13);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,dX(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('dX=B/(vol*S)'); 
        end
        if P_dX(1,2)==1
        ylim([P_dX(1,3),P_dX(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs dX(t)')
end
end

% vol = STD/S                               vol(i,j)=STD(i,j)/SS(i,j);
if P_vol(1,1)==1
if Recalculate==1
vol=market(SS_W,dt_W,r,D,N_STD,format_dt,12);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,vol(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('vol = STD/S'); 
        end
        if P_vol(1,2)==1
        ylim([P_vol(1,3),P_vol(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs Volatility(t)')
end
end

% STD = sqrt(sum(s(t)-MEAN)^2/n-1)          STD(i,:)=std(SS_Plot1);
if P_STD(1,1)==1
if Recalculate==1
STD=market(SS_W,dt_W,r,D,N_STD,format_dt,11);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,STD(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('STD = sqrt(sum(s(t)-MEAN)^2/n-1)'); 
        end
        if P_STD(1,2)==1
        ylim([P_STD(1,3),P_STD(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs STD(S,t)')
end
end

% MEAN = sum(S(t))/n                        MEAN(i,:)=mean(SS_Plot1,1);
if P_MEAN(1,1)==1
if Recalculate==1
MEAN=market(SS_W,dt_W,r,D,N_STD,format_dt,10);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,MEAN(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('MEAN = sum(S(t))/n'); 
        end
        if P_MEAN(1,2)==1
        ylim([P_MEAN(1,3),P_MEAN(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs MEAN(S,t)')
end
end

% b = ds - a = vol*dX                       b(i,j)=ds(i,j)-a(i,j);
if P_b(1,1)==1
if Recalculate==1
b=market(SS_W,dt_W,r,D,N_STD,format_dt,9);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,b(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('b = ds - a = vol*dX'); 
        end
        if P_b(1,2)==1
        ylim([P_b(1,3),P_b(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs b(t)')
end
end

% B = dS - A = S*vol*dX                     B(i,j)=dS(i,j)-A(i,j)*dt(i);
if P_B(1,1)==1
if Recalculate==1
B=market(SS_W,dt_W,r,D,N_STD,format_dt,8);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,B(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('B = dS - A = S*vol*dX'); 
        end
        if P_B(1,2)==1
        ylim([P_B(1,3),P_B(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs B(S,t)')
end
end

% a = (r-D)dt                               a(i,j)=(r-D)*dt(i);
if P_a(1,1)==1
if Recalculate==1
a=market(SS_W,dt_W,r,D,N_STD,format_dt,7);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,a(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('a = (r-D)dt'); 
        end
        if P_a(1,2)==1
        ylim([P_a(1,3),P_a(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs a(t)')
end
end

% A = S(r-D)dt                              A(i,j)=SS(i,j)*(r-D);
if P_A(1,1)==1
if Recalculate==1
A=market(SS_W,dt_W,r,D,N_STD,format_dt,6);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,A(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('A = S(r-D)dt'); 
        end
        if P_A(1,2)==1
        ylim([P_A(1,3),P_A(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs A(S,t)')
end
end

% ds = dS/S(t)                              ds(i,j)=dS(i,j)/SS(i,j);
if P_ds(1,1)==1
if Recalculate==1
ds=market(SS_W,dt_W,r,D,N_STD,format_dt,5);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,ds(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('ds = dS/S(t) = (S(t+1)-S(t))/S(t)'); 
        end
        if P_ds(1,2)==1
        ylim([P_ds(1,3),P_ds(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs ds')
end
end

% dS = S(t+1)-S(t)                          dS(i,j)=SS(i+1,j)-SS(i,j);
if P_dS(1,1)==1
if Recalculate==1
dS=market(SS_W,dt_W,r,D,N_STD,format_dt,4);
end
figure;
for i=1:size(SS_W,2)
    subplot(size(SS_W,2),1,i);
    plot(name,dS(:,i));
    legend(STOCK_TO_ANALIZE(i,:));
        if i==1
        title('dS = S(t+1)-S(t)'); 
        end
        if P_dS(1,2)==1
        ylim([P_dS(1,3),P_dS(1,4)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs dS ($)')
end
end

% dt
% dt = 1 year / number of data                   
% dt=1/253 year 2001; dt=1/252 others; 
% format_dt=2
% dt = number of data,vacations,weekneds/365 or 366
if P_dt(1,1)==1
if Recalculate==1
dt=market(SS_W,dt_W,r,D,N_STD,format_dt,3);
end
figure;
plot(name(:,1),dt);
if format_dt==2
title('dt = (number of data + vacations + weekneds)/365 or 366');
else
title('dt = dt = 1 year / number of data');
end
legend('dt');
if P_dt(1,2)==1
ylim([P_dt(1,3),P_dt(1,4)]);
end
xlim([xlim_down,xlim_up]);
xlabel('TIME vs dt')
end

% Stock price

if P_SS(1,1)==1
if Recalculate==1
SS_Plot=market(SS_W,dt_W,r,D,N_STD,format_dt,16);
end
figure;
plot(name(:,1),SS_Plot);
legend(STOCK_TO_ANALIZE);
title('Stock price ($)');
if P_SS(1,2)==1
ylim([P_SS(1,3),P_SS(1,4)]);
end
xlim([xlim_down,xlim_up]);
xlabel('TIME vs Stock price($$)')
end

% error of calculation 
if P_error(1,1) == 1
for i=1:size(dS,1)
for j=1:size(dS,2)
dS_part(i,j)=SS_W(i,j)*(r-D)*dt(i)+SS_W(i,j)*vol(i,j)*sqrt(dt(i))*z_X(i,j);
ds_part(i,j)=(r-D)*dt(i)+vol(i,j)*sqrt(dt(i))*z_X(i,j);
error_S(i,j)=SS_W(i+1,j)-(SS_W(i,j)+SS_W(i,j)*(r-D)*dt(i)+SS_W(i,j)*vol(i,j)*sqrt(dt(i))*z_X(i,j));
error_s(i,j)=SS_W(i+1,j)-(SS_W(i,j)+((r-D)*dt(i)+vol(i,j)*sqrt(dt(i))*z_X(i,j))*SS_W(i,j));
end
end
error_dS=dS-dS_part;
error_ds=ds-ds_part;
error_dS(1,:)=zeros(1,size(dS,2));
error_ds(1,:)=zeros(1,size(dS,2));
error_S(1,:)=zeros(1,size(dS,2));
error_s(1,:)=zeros(1,size(dS,2));
error_1=sum(sum(error_dS));
error_2=sum(sum(error_ds));
error_3=sum(sum(error_S));
error_4=sum(sum(error_s));
error=[error_dS,error_ds,error_S,error_s];
error_sum=[error_1;error_2;error_3;error_4];
figure
subplot(4,1,1);
plot(name(:,1),error_dS);
legend('error dS');
YLABEL(error_1);
        if P_error(1,2)==1
        ylim([P_error1(1,1),P_error1(1,2)]);
        end
        xlim([xlim_down,xlim_up]);
title('Error of calculations');
subplot(4,1,2);
plot(name(:,1),error_ds);
legend('error ds');
YLABEL(error_2);
        if P_error(1,2)==1
        ylim([P_error2(1,1),P_error2(1,2)]);
        end
        xlim([xlim_down,xlim_up]);
subplot(4,1,3);
plot(name(:,1),error_S);
legend('error S');
YLABEL(error_3);
        if P_error(1,2)==1
        ylim([P_error3(1,1),P_error3(1,2)]);
        end
        xlim([xlim_down,xlim_up]);
subplot(4,1,4);
plot(name(:,1),error_s);
legend('error s');
YLABEL(error_4);
        if P_error(1,2)==1
        ylim([P_error4(1,1),P_error4(1,2)]);
        end
        xlim([xlim_down,xlim_up]);
        xlabel('TIME vs error')
end
Error_of_calculations_of_stock_parameters =sum(error_sum)
%
COMMENTS = 'Routine finish 100%';
COMMENTS
Property_of = 'Klaus Schmitz (Comments: schmitz@maths.ox.ac.uk)';
Property_of
%
% clean workspace
%
clear N i j time_work ans N_STD r D INTERNATIONAL LONDON Res format_dt r error_*;
clear i j dS_part ds_part P_* Recalculate errorsum display;
clear LEGEND_* N_*_legend Max_legend xlim_up xlim_down conta ans COMMENTS;
clear matriz_legend Error_of_calculations_of_stock_parameters error;
%
